MappingServiceGraph
===================

.. currentmodule:: curies.mapping_service

.. autoclass:: MappingServiceGraph
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MappingServiceGraph.triples

   .. rubric:: Methods Documentation

   .. automethod:: triples
